==> projen-0.27.22.tar.gz: package/lib/github/stale.d.ts <==
import { Component } from '../component';
import { GitHub } from './github';
/**
 * (experimental) Options for `Stale`.
 *
 * @experimental
 */
export interface StaleOptions {
    /**
     * (experimental) How to handle stale pull requests.
     *
     * @default - By default, pull requests with no activity will be marked as
     * stale after 14 days and closed within 2 days with relevant comments.
     * @experimental
     */
    readonly pullRequest?: StaleBehavior;
    /**
     * (experimental) How to handle stale issues.
     *
     * @default - By default, stale issues with no activity will be marked as
     * stale after 60 days and closed within 7 days.
     * @experimental
     */
    readonly issues?: StaleBehavior;
}
/**
 * (experimental) Stale behavior.
 *
 * @experimental
 */
export interface StaleBehavior {
    /**
     * (experimental) Determines if this behavior is enabled.
     *
     * Same as setting `daysBeforeStale` and `daysBeforeClose` to `-1`.
     *
     * @default true
     * @experimental
     */
    readonly enabled?: boolean;
    /**
     * (experimental) How many days until the issue or pull request is marked as "Stale".
     *
     * Set to -1 to disable.
     *
     * @default -
     * @experimental
     */
    readonly daysBeforeStale?: number;
    /**
     * (experimental) Days until the issue/PR is closed after it is marked as "Stale".
     *
     * Set to -1 to disable.
     *
     * @default -
     * @experimental
     */
    readonly daysBeforeClose?: number;
    /**
     * (experimental) The comment to add to the issue/PR when it becomes stale.
     *
     * @default "This pull request is now marked as stale because hasn\'t seen activity for a while. Add a comment or it will be closed soon."
     * @experimental
     */
    readonly staleMessage?: string;
    /**
     * (experimental) The comment to add to the issue/PR when it's closed.
     *
     * @default "Closing this pull request as it hasn\'t seen activity for a while. Please add a comment
     * @experimental
     * @mentioning a maintainer when you are ready to continue."
     */
    readonly closeMessage?: string;
    /**
     * (experimental) The label to apply to the issue/PR when it becomes stale.
     *
     * @default "Stale"
     * @experimental
     */
    readonly staleLabel?: string;
}
/**
 * (experimental) Warns and then closes issues and PRs that have had no activity for a specified amount of time.
 *
 * The default configuration will:
 *
 *   * Add a "Stale" label to pull requests after 14 days and closed after 2 days
 *   * Add a "Stale" label to issues after 60 days and closed after 7 days
 *   * If a comment is added, the label will be removed and timer is restarted.
 *
 * @see https://github.com/actions/stale
 * @experimental
 */
export declare class Stale extends Component {
    /**
     * @experimental
     */
    constructor(github: GitHub, options?: StaleOptions);
}

==> projen-0.40.1.tar.gz: package/lib/github/stale.d.ts <==
import { Component } from '../component';
import { GitHub } from './github';
/**
 * (experimental) Options for `Stale`.
 *
 * @experimental
 */
export interface StaleOptions {
    /**
     * (experimental) How to handle stale pull requests.
     *
     * @default - By default, pull requests with no activity will be marked as
     * stale after 14 days and closed within 2 days with relevant comments.
     * @experimental
     */
    readonly pullRequest?: StaleBehavior;
    /**
     * (experimental) How to handle stale issues.
     *
     * @default - By default, stale issues with no activity will be marked as
     * stale after 60 days and closed within 7 days.
     * @experimental
     */
    readonly issues?: StaleBehavior;
    /**
     * (experimental) Github Runner selection labels.
     *
     * @default ["ubuntu-latest"]
     * @experimental
     */
    readonly runsOn?: string[];
}
/**
 * (experimental) Stale behavior.
 *
 * @experimental
 */
export interface StaleBehavior {
    /**
     * (experimental) Determines if this behavior is enabled.
     *
     * Same as setting `daysBeforeStale` and `daysBeforeClose` to `-1`.
     *
     * @default true
     * @experimental
     */
    readonly enabled?: boolean;
    /**
     * (experimental) How many days until the issue or pull request is marked as "Stale".
     *
     * Set to -1 to disable.
     *
     * @default -
     * @experimental
     */
    readonly daysBeforeStale?: number;
    /**
     * (experimental) Days until the issue/PR is closed after it is marked as "Stale".
     *
     * Set to -1 to disable.
     *
     * @default -
     * @experimental
     */
    readonly daysBeforeClose?: number;
    /**
     * (experimental) The comment to add to the issue/PR when it becomes stale.
     *
     * @default "This pull request is now marked as stale because hasn\'t seen activity for a while. Add a comment or it will be closed soon."
     * @experimental
     */
    readonly staleMessage?: string;
    /**
     * (experimental) The comment to add to the issue/PR when it's closed.
     *
     * @default "Closing this pull request as it hasn\'t seen activity for a while. Please add a comment
     * @experimental
     * @mentioning a maintainer when you are ready to continue."
     */
    readonly closeMessage?: string;
    /**
     * (experimental) The label to apply to the issue/PR when it becomes stale.
     *
     * @default "Stale"
     * @experimental
     */
    readonly staleLabel?: string;
}
/**
 * (experimental) Warns and then closes issues and PRs that have had no activity for a specified amount of time.
 *
 * The default configuration will:
 *
 *   * Add a "Stale" label to pull requests after 14 days and closed after 2 days
 *   * Add a "Stale" label to issues after 60 days and closed after 7 days
 *   * If a comment is added, the label will be removed and timer is restarted.
 *
 * @see https://github.com/actions/stale
 * @experimental
 */
export declare class Stale extends Component {
    /**
     * @experimental
     */
    constructor(github: GitHub, options?: StaleOptions);
}
